==> foundations-0.3.0.tgz: package/color/variables.js <==
export const vdsColorPurple50 = '#faf0ff';
export const vdsColorPurple100 = '#f5e0ff';
export const vdsColorPurple200 = '#e4b6fb';
export const vdsColorPurple300 = '#d58df9';
export const vdsColorPurple400 = '#c461f7';
export const vdsColorPurple500 = '#b12df4';
export const vdsColorPurple550 = '#990ae3';
export const vdsColorPurple600 = '#8c07d0';
export const vdsColorPurple700 = '#6d02a3';
export const vdsColorPurple800 = '#4e0174';
export const vdsColorPurple900 = '#29003e';
export const vdsColorPurple950 = '#1f002e';
export const vdsColorBeige50 = '#f9f1ec';
export const vdsColorBeige100 = '#ede1d8';
export const vdsColorBeige200 = '#d7c3b5';
export const vdsColorBeige300 = '#bba494';
export const vdsColorBeige400 = '#a08877';
export const vdsColorBeige500 = '#807268';
export const vdsColorBeige600 = '#665e58';
export const vdsColorBeige700 = '#4f4741';
export const vdsColorBeige800 = '#3b332d';
export const vdsColorBeige900 = '#241c16';
export const vdsColorBeige950 = '#170f09';
export const vdsColorTeal50 = '#edf5f5';
export const vdsColorTeal100 = '#d5eae9';
export const vdsColorTeal200 = '#a1cfcd';
export const vdsColorTeal300 = '#6eb5b2';
export const vdsColorTeal400 = '#3a9b96';
export const vdsColorTeal500 = '#00847e';
export const vdsColorTeal600 = '#006c67';
export const vdsColorTeal700 = '#02534f';
export const vdsColorTeal800 = '#063c39';
export const vdsColorTeal900 = '#032220';
export const vdsColorTeal950 = '#011413';
export const vdsColorGray50 = '#f3f3f8';
export const vdsColorGray100 = '#e5e5eb';
export const vdsColorGray150 = '#d6d6dd';
export const vdsColorGray200 = '#c6c6cd';
export const vdsColorGray300 = '#aaaab0';
export const vdsColorGray400 = '#8d8d94';
export const vdsColorGray500 = '#757579';
export const vdsColorGray600 = '#5f5f63';
export const vdsColorGray700 = '#4a4a4d';
export const vdsColorGray800 = '#353537';
export const vdsColorGray850 = '#2a2a2c';
export const vdsColorGray900 = '#1e1e20';
export const vdsColorGray950 = '#111111';
export const vdsColorGreen50 = '#e1f9ec';
export const vdsColorGreen100 = '#c5efd9';
export const vdsColorGreen200 = '#79d9a7';
export const vdsColorGreen300 = '#3dbf7c';
export const vdsColorGreen400 = '#1fa15e';
export const vdsColorGreen500 = '#018842';
export const vdsColorGreen600 = '#017037';
export const vdsColorGreen700 = '#02562b';
export const vdsColorGreen800 = '#003e1e';
export const vdsColorGreen900 = '#002411';
export const vdsColorGreen950 = '#00150a';
export const vdsColorRed50 = '#fff0f5';
export const vdsColorRed100 = '#ffdde8';
export const vdsColorRed200 = '#ffafc9';
export const vdsColorRed300 = '#ff80ab';
export const vdsColorRed400 = '#fb4885';
export const vdsColorRed500 = '#e4175c';
export const vdsColorRed600 = '#c00543';
export const vdsColorRed700 = '#980233';
export const vdsColorRed800 = '#700025';
export const vdsColorRed900 = '#440016';
export const vdsColorRed950 = '#2c000e';
export const vdsColorOrange50 = '#fff2de';
export const vdsColorOrange100 = '#ffe1b3';
export const vdsColorOrange200 = '#f9bb5b';
export const vdsColorOrange300 = '#f39200';
export const vdsColorOrange400 = '#cc7a00';
export const vdsColorOrange500 = '#a86602';
export const vdsColorOrange600 = '#8b5301';
export const vdsColorOrange700 = '#6a4102';
export const vdsColorOrange800 = '#4c2f03';
export const vdsColorOrange900 = '#2b1b03';
export const vdsColorOrange950 = '#1a0f00';
export const vdsColorBlue50 = '#e8f6ff';
export const vdsColorBlue100 = '#caeaff';
export const vdsColorBlue200 = '#91cdf4';
export const vdsColorBlue300 = '#62b2e7';
export const vdsColorBlue400 = '#3694d3';
export const vdsColorBlue500 = '#0078cb';
export const vdsColorBlue600 = '#0063a6';
export const vdsColorBlue700 = '#014d80';
export const vdsColorBlue800 = '#03385b';
export const vdsColorBlue900 = '#002036';
export const vdsColorBlue950 = '#011320';
export const vdsColorTransparentBlack50 = 'rgba(0, 0, 0, 0.05)';
export const vdsColorTransparentBlack100 = 'rgba(0, 0, 0, 0.1)';
export const vdsColorTransparentBlack150 = 'rgba(0, 0, 0, 0.16)';
export const vdsColorTransparentBlack200 = 'rgba(0, 0, 0, 0.22)';
export const vdsColorTransparentBlack300 = 'rgba(0, 0, 0, 0.33)';
export const vdsColorTransparentBlack400 = 'rgba(0, 0, 0, 0.44)';
export const vdsColorTransparentBlack500 = 'rgba(0, 0, 0, 0.54)';
export const vdsColorTransparentBlack600 = 'rgba(0, 0, 0, 0.62)';
export const vdsColorTransparentBlack700 = 'rgba(0, 0, 0, 0.71)';
export const vdsColorTransparentBlack800 = 'rgba(0, 0, 0, 0.8)';
export const vdsColorTransparentBlack850 = 'rgba(0, 0, 0, 0.84)';
export const vdsColorTransparentBlack900 = 'rgba(0, 0, 0, 0.88)';
export const vdsColorTransparentBlack950 = 'rgba(0, 0, 0, 0.93)';
export const vdsColorTransparentWhite50 = 'rgba(255, 255, 255, 0.07)';
export const vdsColorTransparentWhite100 = 'rgba(255, 255, 255, 0.11)';
export const vdsColorTransparentWhite150 = 'rgba(255, 255, 255, 0.16)';
export const vdsColorTransparentWhite200 = 'rgba(255, 255, 255, 0.21)';
export const vdsColorTransparentWhite300 = 'rgba(255, 255, 255, 0.29)';
export const vdsColorTransparentWhite400 = 'rgba(255, 255, 255, 0.37)';
export const vdsColorTransparentWhite500 = 'rgba(255, 255, 255, 0.46)';
export const vdsColorTransparentWhite600 = 'rgba(255, 255, 255, 0.55)';
export const vdsColorTransparentWhite700 = 'rgba(255, 255, 255, 0.66)';
export const vdsColorTransparentWhite800 = 'rgba(255, 255, 255, 0.79)';
export const vdsColorTransparentWhite850 = 'rgba(255, 255, 255, 0.84)';
export const vdsColorTransparentWhite900 = 'rgba(255, 255, 255, 0.89)';
export const vdsColorTransparentWhite950 = 'rgba(255, 255, 255, 0.95)';
export const vdsColorFunctionalBlack = '#000000';
export const vdsColorFunctionalWhite = '#ffffff';
export const vdsColorFunctionalTransparent = 'rgba(255, 255, 255, 0)';
export const vdsColorBrandDeepPurple = '#29003e';
export const vdsColorBrandCorePurple = '#990ae3';
export const vdsColorBrandLightPurple = '#f5e0ff';
export const vdsColorBrandDeepBeige = '#4f4741';
export const vdsColorBrandBeige = '#ede1d8';
export const vdsColorBrandLightBeige = '#f9f1ec';
export const vdsColorBrandOffBlack = '#1e1e20';
export const vdsColorBrandWhite = '#ffffff';
export const vdsColorTextDefault = 'rgba(0, 0, 0, 0.84)';
export const vdsColorTextMedium = 'rgba(0, 0, 0, 0.62)';
export const vdsColorTextWeak = 'rgba(0, 0, 0, 0.44)';
export const vdsColorTextDefaultNegative = 'rgba(255, 255, 255, 0.84)';
export const vdsColorTextMediumNegative = 'rgba(255, 255, 255, 0.55)';
export const vdsColorTextWeakNegative = 'rgba(255, 255, 255, 0.37)';
export const vdsColorTextInteractivePrimary = '#4e0174';
export const vdsColorTextInteractivePrimaryHover = '#6d02a3';
export const vdsColorTextInteractivePrimaryActive = '#8c07d0';
export const vdsColorTextInteractiveOnPrimary = '#ffffff';
export const vdsColorTextInteractiveOnPrimaryNegative = '#4e0174';
export const vdsColorTextInteractivePrimaryNegative = '#f5e0ff';
export const vdsColorTextInteractivePrimaryNegativeHover = '#e4b6fb';
export const vdsColorTextInteractivePrimaryNegativeActive = '#d58df9';
export const vdsColorTextInteractiveGhost = '#6d02a3';
export const vdsColorTextInteractiveGhostActive = '#4e0174';
export const vdsColorTextInteractiveGhostNegative = '#d58df9';
export const vdsColorTextInteractiveGhostNegativeActive = '#e4b6fb';
export const vdsColorTextInteractiveOnExpressive = '#ffffff';
export const vdsColorTextInteractiveOnExpressiveNegative = '#ffffff';
export const vdsColorTextInteractiveOnExpressiveNegativeHover = '#29003e';
export const vdsColorTextInteractiveOnExpressiveNegativeActive = '#29003e';
export const vdsColorTextInteractiveOnDestructive = '#ffffff';
export const vdsColorTextStatusErrorStrong = '#980233';
export const vdsColorTextStatusErrorMedium = '#e4175c';
export const vdsColorTextStatusSuccessStrong = '#02562b';
export const vdsColorTextStatusSuccessMedium = '#018842';
export const vdsColorTextStatusWarningStrong = '#6a4102';
export const vdsColorTextStatusWarningMedium = '#cc7a00';
export const vdsColorTextStatusInfoStrong = '#014d80';
export const vdsColorTextStatusInfoMedium = '#0078cb';
export const vdsColorTextStatusNeutral = 'rgba(0, 0, 0, 0.71)';
export const vdsColorTextStatusSpecial = '#4e0174';
export const vdsColorTextStatusAttention = '#ffffff';
export const vdsColorTextToneOnTonePrimary = '#f5e0ff';
export const vdsColorTextToneOnToneSecondary = '#29003e';
export const vdsColorTextToneOnToneTertiary = '#4f4741';
export const vdsColorBackgroundPrimary = '#ffffff';
export const vdsColorBackgroundSecondary = '#f3f3f8';
export const vdsColorBackgroundInteractivePrimary = '#4e0174';
export const vdsColorBackgroundInteractivePrimaryHover = '#6d02a3';
export const vdsColorBackgroundInteractivePrimaryActive = '#8c07d0';
export const vdsColorBackgroundInteractivePrimaryNegative = '#f5e0ff';
export const vdsColorBackgroundInteractivePrimaryNegativeHover = '#e4b6fb';
export const vdsColorBackgroundInteractivePrimaryNegativeActive = '#d58df9';
export const vdsColorBackgroundInteractiveExpressive = '#990ae3';
export const vdsColorBackgroundInteractiveExpressiveHover = '#6d02a3';
export const vdsColorBackgroundInteractiveExpressiveActive = '#4e0174';
export const vdsColorBackgroundInteractiveExpressiveNegative = '#990ae3';
export const vdsColorBackgroundInteractiveExpressiveNegativeHover = '#c461f7';
export const vdsColorBackgroundInteractiveExpressiveNegativeActive = '#d58df9';
export const vdsColorBackgroundInteractiveDisabled = 'rgba(0, 0, 0, 0.1)';
export const vdsColorBackgroundInteractiveDisabledNegative =
  'rgba(255, 255, 255, 0.11)';
export const vdsColorBackgroundInteractiveGhost = 'rgba(255, 255, 255, 0)';
export const vdsColorBackgroundInteractiveGhostHover = '#f5e0ff';
export const vdsColorBackgroundInteractiveGhostNegativeHover = '#4e0174';
export const vdsColorBackgroundInteractiveGhostActive = '#e4b6fb';
export const vdsColorBackgroundInteractiveGhostNegativeActive = '#6d02a3';
export const vdsColorBackgroundInteractiveSelected = '#4e0174';
export const vdsColorBackgroundInteractiveSelectedHover = '#6d02a3';
export const vdsColorBackgroundInteractiveInactive = 'rgba(0, 0, 0, 0.05)';
export const vdsColorBackgroundInteractiveInactiveStrong = '#757579';
export const vdsColorBackgroundInteractiveReadOnly = 'rgba(0, 0, 0, 0.05)';
export const vdsColorBackgroundInteractiveDestructive = '#e4175c';
export const vdsColorBackgroundInteractiveDestructiveHover = '#c00543';
export const vdsColorBackgroundInteractiveDestructiveActive = '#980233';
export const vdsColorBackgroundStatusInfo = '#e8f6ff';
export const vdsColorBackgroundStatusInfoStrong = '#caeaff';
export const vdsColorBackgroundStatusSuccess = '#e1f9ec';
export const vdsColorBackgroundStatusSuccessStrong = '#c5efd9';
export const vdsColorBackgroundStatusError = '#fff0f5';
export const vdsColorBackgroundStatusErrorStrong = '#ffdde8';
export const vdsColorBackgroundStatusWarning = '#fff2de';
export const vdsColorBackgroundStatusWarningStrong = '#ffe1b3';
export const vdsColorBackgroundStatusNeutral = 'rgba(0, 0, 0, 0.1)';
export const vdsColorBackgroundStatusSpecial = '#f5e0ff';
export const vdsColorBackgroundStatusAttention = '#6d02a3';
export const vdsColorBackgroundToneOnTonePrimary = '#29003e';
export const vdsColorBackgroundToneOnToneSecondary = '#f5e0ff';
export const vdsColorBackgroundToneOnToneTertiary = '#ede1d8';
export const vdsColorBorderStrong = 'rgba(0, 0, 0, 0.54)';
export const vdsColorBorderMedium = 'rgba(0, 0, 0, 0.33)';
export const vdsColorBorderWeak = 'rgba(0, 0, 0, 0.16)';
export const vdsColorBorderWeakNegative = 'rgba(255, 255, 255, 0.16)';
export const vdsColorBorderInteractivePrimary = '#4e0174';
export const vdsColorBorderInteractiveFocus = '#0078cb';
export const vdsColorBorderInteractiveSubtle = 'rgba(0, 0, 0, 0.33)';
export const vdsColorBorderInteractiveSubtleHover = '#4e0174';
export const vdsColorBorderInteractiveSelected = '#4e0174';
export const vdsColorBorderInteractivePrimaryNegative = '#f5e0ff';
export const vdsColorBorderStatusError = '#e4175c';
export const vdsColorBorderStatusWarning = '#cc7a00';
export const vdsColorBorderStatusInfo = '#0078cb';
export const vdsColorBorderStatusSuccess = '#018842';
export const vdsColorOverlayDefault = 'rgba(0, 0, 0, 0.33)';

==> foundations-0.4.0.tgz: package/color/variables.js <==
export const vdsColorPurple50 = '#faf0ff';
export const vdsColorPurple100 = '#f5e0ff';
export const vdsColorPurple200 = '#e4b6fb';
export const vdsColorPurple300 = '#d58df9';
export const vdsColorPurple400 = '#c461f7';
export const vdsColorPurple550 = '#990ae3';
export const vdsColorPurple600 = '#8c07d0';
export const vdsColorPurple700 = '#6d02a3';
export const vdsColorPurple800 = '#4e0174';
export const vdsColorPurple900 = '#29003e';
export const vdsColorPurple950 = '#1f002e';
export const vdsColorBeige50 = '#f9f1ec';
export const vdsColorBeige100 = '#ede1d8';
export const vdsColorBeige200 = '#d7c3b5';
export const vdsColorBeige300 = '#bba494';
export const vdsColorBeige400 = '#a08877';
export const vdsColorBeige500 = '#807268';
export const vdsColorBeige600 = '#665e58';
export const vdsColorBeige700 = '#4f4741';
export const vdsColorBeige800 = '#3b332d';
export const vdsColorBeige900 = '#241c16';
export const vdsColorBeige950 = '#170f09';
export const vdsColorTeal50 = '#edf5f5';
export const vdsColorTeal100 = '#d5eae9';
export const vdsColorTeal200 = '#a1cfcd';
export const vdsColorTeal300 = '#6eb5b2';
export const vdsColorTeal400 = '#3a9b96';
export const vdsColorTeal500 = '#00847e';
export const vdsColorTeal600 = '#006c67';
export const vdsColorTeal700 = '#02534f';
export const vdsColorTeal800 = '#063c39';
export const vdsColorTeal900 = '#032220';
export const vdsColorTeal950 = '#011413';
export const vdsColorGray50 = '#f3f3f8';
export const vdsColorGray100 = '#e5e5eb';
export const vdsColorGray150 = '#d6d6dd';
export const vdsColorGray200 = '#c6c6cd';
export const vdsColorGray300 = '#aaaab0';
export const vdsColorGray400 = '#8d8d94';
export const vdsColorGray500 = '#757579';
export const vdsColorGray600 = '#5f5f63';
export const vdsColorGray700 = '#4a4a4d';
export const vdsColorGray800 = '#353537';
export const vdsColorGray850 = '#2a2a2c';
export const vdsColorGray900 = '#1e1e20';
export const vdsColorGray950 = '#111111';
export const vdsColorGreen50 = '#e1f9ec';
export const vdsColorGreen100 = '#c5efd9';
export const vdsColorGreen200 = '#79d9a7';
export const vdsColorGreen300 = '#3dbf7c';
export const vdsColorGreen400 = '#1fa15e';
export const vdsColorGreen500 = '#018842';
export const vdsColorGreen600 = '#017037';
export const vdsColorGreen700 = '#02562b';
export const vdsColorGreen800 = '#003e1e';
export const vdsColorGreen900 = '#002411';
export const vdsColorGreen950 = '#00150a';
export const vdsColorRed50 = '#fff0f5';
export const vdsColorRed100 = '#ffdde8';
export const vdsColorRed200 = '#ffafc9';
export const vdsColorRed300 = '#ff80ab';
export const vdsColorRed400 = '#fb4885';
export const vdsColorRed500 = '#e4175c';
export const vdsColorRed600 = '#c00543';
export const vdsColorRed700 = '#980233';
export const vdsColorRed800 = '#700025';
export const vdsColorRed900 = '#440016';
export const vdsColorRed950 = '#2c000e';
export const vdsColorOrange50 = '#fff2de';
export const vdsColorOrange100 = '#ffe1b3';
export const vdsColorOrange200 = '#f9bb5b';
export const vdsColorOrange300 = '#f39200';
export const vdsColorOrange400 = '#cc7a00';
export const vdsColorOrange500 = '#a86602';
export const vdsColorOrange600 = '#8b5301';
export const vdsColorOrange700 = '#6a4102';
export const vdsColorOrange800 = '#4c2f03';
export const vdsColorOrange900 = '#2b1b03';
export const vdsColorOrange950 = '#1a0f00';
export const vdsColorBlue50 = '#e8f6ff';
export const vdsColorBlue100 = '#caeaff';
export const vdsColorBlue200 = '#91cdf4';
export const vdsColorBlue300 = '#62b2e7';
export const vdsColorBlue400 = '#3694d3';
export const vdsColorBlue500 = '#0078cb';
export const vdsColorBlue600 = '#0063a6';
export const vdsColorBlue700 = '#014d80';
export const vdsColorBlue800 = '#03385b';
export const vdsColorBlue900 = '#002036';
export const vdsColorBlue950 = '#011320';
export const vdsColorTransparentBlack50 = 'rgba(0, 0, 0, 0.05)';
export const vdsColorTransparentBlack100 = 'rgba(0, 0, 0, 0.1)';
export const vdsColorTransparentBlack150 = 'rgba(0, 0, 0, 0.16)';
export const vdsColorTransparentBlack200 = 'rgba(0, 0, 0, 0.22)';
export const vdsColorTransparentBlack300 = 'rgba(0, 0, 0, 0.33)';
export const vdsColorTransparentBlack400 = 'rgba(0, 0, 0, 0.44)';
export const vdsColorTransparentBlack500 = 'rgba(0, 0, 0, 0.54)';
export const vdsColorTransparentBlack600 = 'rgba(0, 0, 0, 0.62)';
export const vdsColorTransparentBlack700 = 'rgba(0, 0, 0, 0.71)';
export const vdsColorTransparentBlack800 = 'rgba(0, 0, 0, 0.8)';
export const vdsColorTransparentBlack850 = 'rgba(0, 0, 0, 0.84)';
export const vdsColorTransparentBlack900 = 'rgba(0, 0, 0, 0.88)';
export const vdsColorTransparentBlack950 = 'rgba(0, 0, 0, 0.93)';
export const vdsColorTransparentWhite50 = 'rgba(255, 255, 255, 0.07)';
export const vdsColorTransparentWhite100 = 'rgba(255, 255, 255, 0.11)';
export const vdsColorTransparentWhite150 = 'rgba(255, 255, 255, 0.16)';
export const vdsColorTransparentWhite200 = 'rgba(255, 255, 255, 0.21)';
export const vdsColorTransparentWhite300 = 'rgba(255, 255, 255, 0.29)';
export const vdsColorTransparentWhite400 = 'rgba(255, 255, 255, 0.37)';
export const vdsColorTransparentWhite500 = 'rgba(255, 255, 255, 0.46)';
export const vdsColorTransparentWhite600 = 'rgba(255, 255, 255, 0.55)';
export const vdsColorTransparentWhite700 = 'rgba(255, 255, 255, 0.66)';
export const vdsColorTransparentWhite800 = 'rgba(255, 255, 255, 0.79)';
export const vdsColorTransparentWhite850 = 'rgba(255, 255, 255, 0.84)';
export const vdsColorTransparentWhite900 = 'rgba(255, 255, 255, 0.89)';
export const vdsColorTransparentWhite950 = 'rgba(255, 255, 255, 0.95)';
export const vdsColorFunctionalBlack = '#000000';
export const vdsColorFunctionalWhite = '#ffffff';
export const vdsColorFunctionalTransparent = 'rgba(255, 255, 255, 0)';
export const vdsColorBrandDeepPurple = '#29003e';
export const vdsColorBrandCorePurple = '#990ae3';
export const vdsColorBrandLightPurple = '#f5e0ff';
export const vdsColorBrandDeepBeige = '#4f4741';
export const vdsColorBrandBeige = '#ede1d8';
export const vdsColorBrandLightBeige = '#f9f1ec';
export const vdsColorBrandOffBlack = '#1e1e20';
export const vdsColorBrandWhite = '#ffffff';
export const vdsColorTextDefault = 'rgba(0, 0, 0, 0.84)';
export const vdsColorTextMedium = 'rgba(0, 0, 0, 0.62)';
export const vdsColorTextWeak = 'rgba(0, 0, 0, 0.44)';
export const vdsColorTextDefaultNegative = 'rgba(255, 255, 255, 0.84)';
export const vdsColorTextMediumNegative = 'rgba(255, 255, 255, 0.55)';
export const vdsColorTextWeakNegative = 'rgba(255, 255, 255, 0.37)';
export const vdsColorTextInteractivePrimary = '#4e0174';
export const vdsColorTextInteractivePrimaryHover = '#6d02a3';
export const vdsColorTextInteractivePrimaryActive = '#8c07d0';
export const vdsColorTextInteractiveOnPrimary = '#ffffff';
export const vdsColorTextInteractiveOnPrimaryNegative = '#4e0174';
export const vdsColorTextInteractivePrimaryNegative = '#f5e0ff';
export const vdsColorTextInteractivePrimaryNegativeHover = '#e4b6fb';
export const vdsColorTextInteractivePrimaryNegativeActive = '#d58df9';
export const vdsColorTextInteractiveGhost = '#6d02a3';
export const vdsColorTextInteractiveGhostActive = '#4e0174';
export const vdsColorTextInteractiveGhostNegative = '#d58df9';
export const vdsColorTextInteractiveGhostNegativeActive = '#e4b6fb';
export const vdsColorTextInteractiveOnExpressive = '#ffffff';
export const vdsColorTextInteractiveOnExpressiveNegative = '#ffffff';
export const vdsColorTextInteractiveOnExpressiveNegativeHover = '#29003e';
export const vdsColorTextInteractiveOnExpressiveNegativeActive = '#29003e';
export const vdsColorTextInteractiveOnDestructive = '#ffffff';
export const vdsColorTextStatusErrorStrong = '#980233';
export const vdsColorTextStatusErrorMedium = '#e4175c';
export const vdsColorTextStatusSuccessStrong = '#02562b';
export const vdsColorTextStatusSuccessMedium = '#018842';
export const vdsColorTextStatusWarningStrong = '#6a4102';
export const vdsColorTextStatusWarningMedium = '#cc7a00';
export const vdsColorTextStatusInfoStrong = '#014d80';
export const vdsColorTextStatusInfoMedium = '#0078cb';
export const vdsColorTextStatusNeutral = 'rgba(0, 0, 0, 0.71)';
export const vdsColorTextStatusSpecial = '#4e0174';
export const vdsColorTextStatusAttention = '#ffffff';
export const vdsColorTextToneOnTonePrimary = '#f5e0ff';
export const vdsColorTextToneOnToneSecondary = '#29003e';
export const vdsColorTextToneOnToneTertiary = '#4f4741';
export const vdsColorBackgroundPrimary = '#ffffff';
export const vdsColorBackgroundSecondary = '#f3f3f8';
export const vdsColorBackgroundInteractivePrimary = '#4e0174';
export const vdsColorBackgroundInteractivePrimaryHover = '#6d02a3';
export const vdsColorBackgroundInteractivePrimaryActive = '#8c07d0';
export const vdsColorBackgroundInteractivePrimaryNegative = '#f5e0ff';
export const vdsColorBackgroundInteractivePrimaryNegativeHover = '#e4b6fb';
export const vdsColorBackgroundInteractivePrimaryNegativeActive = '#d58df9';
export const vdsColorBackgroundInteractiveExpressive = '#990ae3';
export const vdsColorBackgroundInteractiveExpressiveHover = '#6d02a3';
export const vdsColorBackgroundInteractiveExpressiveActive = '#4e0174';
export const vdsColorBackgroundInteractiveExpressiveNegative = '#990ae3';
export const vdsColorBackgroundInteractiveExpressiveNegativeHover = '#c461f7';
export const vdsColorBackgroundInteractiveExpressiveNegativeActive = '#d58df9';
export const vdsColorBackgroundInteractiveDisabled = 'rgba(0, 0, 0, 0.1)';
export const vdsColorBackgroundInteractiveDisabledNegative =
  'rgba(255, 255, 255, 0.11)';
export const vdsColorBackgroundInteractiveGhost = 'rgba(255, 255, 255, 0)';
export const vdsColorBackgroundInteractiveGhostHover = '#f5e0ff';
export const vdsColorBackgroundInteractiveGhostNegativeHover = '#4e0174';
export const vdsColorBackgroundInteractiveGhostActive = '#e4b6fb';
export const vdsColorBackgroundInteractiveGhostNegativeActive = '#6d02a3';
export const vdsColorBackgroundInteractiveSelected = '#4e0174';
export const vdsColorBackgroundInteractiveSelectedHover = '#6d02a3';
export const vdsColorBackgroundInteractiveInactive = 'rgba(0, 0, 0, 0.05)';
export const vdsColorBackgroundInteractiveInactiveStrong = '#757579';
export const vdsColorBackgroundInteractiveReadOnly = 'rgba(0, 0, 0, 0.05)';
export const vdsColorBackgroundInteractiveDestructive = '#e4175c';
export const vdsColorBackgroundInteractiveDestructiveHover = '#c00543';
export const vdsColorBackgroundInteractiveDestructiveActive = '#980233';
export const vdsColorBackgroundStatusInfo = '#e8f6ff';
export const vdsColorBackgroundStatusInfoStrong = '#caeaff';
export const vdsColorBackgroundStatusSuccess = '#e1f9ec';
export const vdsColorBackgroundStatusSuccessStrong = '#c5efd9';
export const vdsColorBackgroundStatusError = '#fff0f5';
export const vdsColorBackgroundStatusErrorStrong = '#ffdde8';
export const vdsColorBackgroundStatusWarning = '#fff2de';
export const vdsColorBackgroundStatusWarningStrong = '#ffe1b3';
export const vdsColorBackgroundStatusNeutral = 'rgba(0, 0, 0, 0.1)';
export const vdsColorBackgroundStatusSpecial = '#f5e0ff';
export const vdsColorBackgroundStatusAttention = '#6d02a3';
export const vdsColorBackgroundToneOnTonePrimary = '#29003e';
export const vdsColorBackgroundToneOnToneSecondary = '#f5e0ff';
export const vdsColorBackgroundToneOnToneTertiary = '#ede1d8';
export const vdsColorBackgroundToneOnToneQuaternary = '#f9f1ec';
export const vdsColorBorderStrong = 'rgba(0, 0, 0, 0.54)';
export const vdsColorBorderMedium = 'rgba(0, 0, 0, 0.33)';
export const vdsColorBorderWeak = 'rgba(0, 0, 0, 0.16)';
export const vdsColorBorderWeakNegative = 'rgba(255, 255, 255, 0.16)';
export const vdsColorBorderInteractivePrimary = '#4e0174';
export const vdsColorBorderInteractiveFocus = '#0078cb';
export const vdsColorBorderInteractiveSubtle = 'rgba(0, 0, 0, 0.33)';
export const vdsColorBorderInteractiveSubtleHover = '#4e0174';
export const vdsColorBorderInteractiveSelected = '#4e0174';
export const vdsColorBorderInteractivePrimaryNegative = '#f5e0ff';
export const vdsColorBorderStatusError = '#e4175c';
export const vdsColorBorderStatusWarning = '#cc7a00';
export const vdsColorBorderStatusInfo = '#0078cb';
export const vdsColorBorderStatusSuccess = '#018842';
export const vdsColorOverlayDefault = 'rgba(0, 0, 0, 0.33)';
